@@ -172,7 +172,7 @@ void MainWindow::article_selected(QTableWidgetItem *item)
 {
     message->setLabelText("Loading " + item->text());
     message->show();
-    bool existsAlready = QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) + "/AudioWiki/"+ item->text().toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
+    bool existsAlready = QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) +  item->text().toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
     network->retrieveArticle(item->text(), existsAlready);
 }
 
@@ -182,7 +182,7 @@ void MainWindow::openArticleFromLink(QListWidgetItem *item)
         player->hide();
     message->setLabelText("Loading " + item->text());
     message->show();
-    bool existsAlready = QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) + "/AudioWiki/"+ item->text().toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
+    bool existsAlready = QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) +  item->text().toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
     network->retrieveArticle(item->text(), existsAlready);
 }
 
@@ -190,7 +190,7 @@ void MainWindow::playlist_item_selected(QTreeWidgetItem *item, int column)
 {
     message->setLabelText("Opening " + item->text(column));
     message->show();
-    bool existsAlready = QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) + "/AudioWiki/"+ item->text(column).toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
+    bool existsAlready = QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) +  item->text(column).toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
     network->retrieveArticle(item->text(column), existsAlready);
 }
 
@@ -215,7 +215,7 @@ void MainWindow::playlist_selected(QList<QTreeWidgetItem *> items, int column)
     QTreeWidgetItem *item;
     foreach (item, items)
     {
-        bool existsAlready = QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) + "/AudioWiki/"+ item->text(column).toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
+        bool existsAlready = QFile(QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation) +  item->text(column).toLower().normalized(QString::NormalizationForm_D).replace(" ", "_")+".txt").exists();
         network->retrieveArticle(item->text(column), existsAlready);
     }
     player->setPlaylistFocus();
